@@ -16,11 +16,13 @@ def table_of_contents(label_node, fragment=False):
         if nextdepth > depth:
             for i in range(nextdepth, 6):
                 index[i - 1] = 0
-            next_ol = Element('ol')
-            ol.appendChild(next_ol)
-            ol = next_ol
+                
+            for i in range(depth, nextdepth):
+                next_ol = Element('ol')
+                ol.appendChild(next_ol)
+                ol = next_ol
         elif nextdepth < depth:
-            ol = ol.parentNode
+            for i in range(nextdepth, depth): ol = ol.parentNode
             
         depth = nextdepth
             
